==> Shiira2.0src.zip: Shiira2.0src/HMDTAppKit/trunk/source/HMDTAppKit/HMTabItemView.h <==
/*
HMTabItemView.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>

@class HMMouseOverButton;
@class HMTabItemGroupView;
@class HMTabViewItem;
@class HMProgressIndicator;

@interface HMTabItemView : NSView
{
    HMTabViewItem*          _tabViewItem;
    HMTabItemGroupView*     _tabItemGroupView;
    
    HMMouseOverButton*      _closeButton;
    NSProgressIndicator*    _nsProgressIndicator;
    HMProgressIndicator*    _hmProgressIndicator;
    
    NSImageInterpolation    _thumbnailInterpolation;
    
    id                      _delegate;
}

// Initialize
- (id)initWithFrame:(NSRect)frame tabViewItem:(HMTabViewItem*)tabViewItem;

// Tab view item
- (HMTabViewItem*)tabViewItem;
- (HMTabItemGroupView*)tabItemGroupView;
- (void)setTabItemGroupView:(HMTabItemGroupView*)tabItemGroupView;
- (void)detachTabViewItem;

- (NSImageInterpolation)thumbnailInterpolation;
- (void)setThumbnailInterpolation:(NSImageInterpolation)interpolation;

// Buttons
- (NSButton*)closeButton;
- (NSProgressIndicator*)nsProgressIndicator;
- (HMProgressIndicator*)hmProgressIndicator;

// Delegate
- (id)delegate;
- (void)setDelegate:(id)delegate;

@end

@interface NSObject (HMTabItemView)
- (NSMenu*)tabItemView:(HMTabItemView*)view menuForEvent:(NSEvent*)event;
@end

==> Shiira2.2src.zip: Shiira2.2src/HMDTAppKit/trunk/source/HMDTAppKit/HMTabItemView.h <==
/*
HMTabItemView.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>

@class HMMouseOverButton;
@class HMTabItemGroupView;
@class HMTabViewItem;
@class HMProgressIndicator;

@interface HMTabItemView : NSView
{
    HMTabViewItem*          _tabViewItem;
    HMTabItemGroupView*     _tabItemGroupView;
    
    HMMouseOverButton*      _closeButton;
    NSProgressIndicator*    _nsProgressIndicator;
    HMProgressIndicator*    _hmProgressIndicator;
    
    NSImageInterpolation    _thumbnailInterpolation;
    
    id                      _delegate;
}

// Initialize
- (id)initWithFrame:(NSRect)frame tabViewItem:(HMTabViewItem*)tabViewItem;

// Tab view item
- (HMTabViewItem*)tabViewItem;
- (HMTabItemGroupView*)tabItemGroupView;
- (void)setTabItemGroupView:(HMTabItemGroupView*)tabItemGroupView;
- (void)detachTabViewItem;

- (NSImageInterpolation)thumbnailInterpolation;
- (void)setThumbnailInterpolation:(NSImageInterpolation)interpolation;

// Buttons
- (NSButton*)closeButton;
- (NSProgressIndicator*)nsProgressIndicator;
- (HMProgressIndicator*)hmProgressIndicator;

// Delegate
- (id)delegate;
- (void)setDelegate:(id)delegate;

@end

@interface NSObject (HMTabItemViewDelegate)
- (NSMenu*)tabItemView:(HMTabItemView*)view menuForEvent:(NSEvent*)event;
- (void)tabItemViewDoubleClicked:(HMTabItemView*)view;
@end
